Index: src/ia32/builtins-ia32.cc |
=================================================================== |
--- src/ia32/builtins-ia32.cc (revision 2959) |
+++ src/ia32/builtins-ia32.cc (working copy) |
@@ -674,18 +674,18 @@ |
// Allocate an empty JSArray. The allocated array is put into the result |
// register. If the parameter holes is larger than zero an elements backing |
// store is allocated with this size and filled with the hole values. Otherwise |
// the elements backing store is set to the empty FixedArray. |
static void AllocateEmptyJSArray(MacroAssembler* masm, |
Register array_function, |
Register result, |
Register scratch1, |
Register scratch2, |
Register scratch3, |
- int holes, |
+ int initial_capacity, |
Label* gc_required) { |
- ASSERT(holes >= 0); |
+ ASSERT(initial_capacity >= 0); |
// Load the initial map from the array function. |
__ mov(scratch1, FieldOperand(array_function, |
@@ -694,8 +694,8 @@ |
// Allocate the JSArray object together with space for a fixed array with the |
// requested elements. |
int size = JSArray::kSize; |
- if (holes > 0) { |
- size += FixedArray::SizeFor(holes); |
+ if (initial_capacity > 0) { |
+ size += FixedArray::SizeFor(initial_capacity); |
} |
__ AllocateObjectInNewSpace(size, |
result, |
@@ -717,7 +717,7 @@ |
// If no storage is requested for the elements array just set the empty |
// fixed array. |
- if (holes == 0) { |
+ if (initial_capacity == 0) { |
__ mov(FieldOperand(result, JSArray::kElementsOffset), |
Factory::empty_fixed_array()); |
return; |
@@ -737,17 +737,18 @@ |
// scratch2: start of next object |
__ mov(FieldOperand(scratch1, JSObject::kMapOffset), |
Factory::fixed_array_map()); |
- __ mov(FieldOperand(scratch1, Array::kLengthOffset), Immediate(holes)); |
+ __ mov(FieldOperand(scratch1, Array::kLengthOffset), |
+ Immediate(initial_capacity)); |
// Fill the FixedArray with the hole value. Inline the code if short. |
// Reconsider loop unfolding if kPreallocatedArrayElements gets changed. |
static const int kLoopUnfoldLimit = 4; |
ASSERT(kPreallocatedArrayElements <= kLoopUnfoldLimit); |
- if (holes <= kLoopUnfoldLimit) { |
+ if (initial_capacity <= kLoopUnfoldLimit) { |
// Use a scratch register here to have only one reloc info when unfolding |
// the loop. |
__ mov(scratch3, Factory::the_hole_value()); |
- for (int i = 0; i < holes; i++) { |
+ for (int i = 0; i < initial_capacity; i++) { |
__ mov(FieldOperand(scratch1, |
FixedArray::kHeaderSize + i * kPointerSize), |
scratch3); |
@@ -674,18 +674,18 @@ |
// Allocate an empty JSArray. The allocated array is put into the result |
-// register. If the parameter holes is larger than zero an elements backing |
-// store is allocated with this size and filled with the hole values. Otherwise |
-// the elements backing store is set to the empty FixedArray. |
+// register. If the parameter initial_capacity is larger than zero an elements |
+// backing store is allocated with this size and filled with the hole values. |
+// Otherwise the elements backing store is set to the empty FixedArray. |
static void AllocateEmptyJSArray(MacroAssembler* masm, |
Register array_function, |